@@ -1,7 +1,8 @@
 use strict;
 use warnings;
 package Dist::Zilla::App::Command::rjbsver;
-our $VERSION = '0.092361';
+our $VERSION = '0.092830';
+
 
 # ABSTRACT: see what the mantissa for an rjbs-style version is today
 use Dist::Zilla::App -command;
@@ -11,7 +12,7 @@ use DateTime ();
 sub command_names { qw(rjbsver rjv) }
 
 sub run {
-  my $now = DateTime->now(time_zone => 'GMT');
+  my $now = DateTime->now(time_zone => 'America/New_York');
 
   printf "Current version mantissa, assuming N=0, is %s0\n",
     $now->format_cldr('yyDDD');
@@ -29,7 +30,7 @@ Dist::Zilla::App::Command::rjbsver - see what the mantissa for an rjbs-style ver
 
 =head1 VERSION
 
-version 0.092361
+version 0.092830
 
 =head1 AUTHOR
 
